@@ -145,7 +145,7 @@ def get_test_dataset(GCS_DS_PATH, test_tfrec_path, BATCH_SIZE):
 	Rest of the helper functions are implemented.
 	""")
 
-	dataset = load_dataset(tf.io.gfile.glob(GCS_DS_PATH + test_tfrec_path), labeled = False, ordered = False)
+	dataset = load_dataset(tf.io.gfile.glob(GCS_DS_PATH + test_tfrec_path), labeled = False, ordered = True)
 	cnt = 0
 	for data in dataset:
 		cnt += 1
